Learn R Programming

smoothSurv (version 1.5-2)

confint.smoothSurvReg: Confidence Intervals for Regression Parameters of 'smoothSurvReg' Model

Description

Computes confidence intervals for one or more regression related parameters (regression coefficients, scale parameter or regression coefficients in a model for scale) for a 'smoothSurvReg' model.

Usage

## S3 method for class 'smoothSurvReg':
confint(object, parm, level = 0.95,
    method = c("pseudo-variance", "asymptotic"), ...)

Arguments

object
Object of class smoothSurvReg.
parm
A specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
level
The confidence level required.
method
Type of confidence intervals to b calculated. Option pseudo-variance provides confidence intervals derived from inverted minus second derivatives of the penalized log-likelihood (pseudo-variance matrix), option asym
...
Argument included in the function parameters for the compatibility with the generic function.

Value

  • A matrix (or vector) with columns giving lower and upper confidence limits for each parameter. These will be labelled as (1 - level)/2 and 1 - (1 - level)/2 in % (by default 2.5 % and 97.5 %).

See Also

smoothSurvReg