Learn R Programming

smoothSurv (version 2.0.1)

print.smoothSurvReg: Summary and Print for Objects of Class 'smoothSurvReg'

Description

Print a summary information of the fitted model.

For regression coefficients the following information is given:

Value - estimate of the coefficient
Std.Error - estimated standard error based on the pseudo-variance estimate (3.1)
in Kom<U+00E1>rek, Lesaffre and Hilton (2005)
Std.Error2 - estimated standard error based on the asymptotic variance estimate (3.2)
in Kom<U+00E1>rek, Lesaffre and Hilton (2005)
Z - the Wald statistic obtained as Value divided by Std.Error
Z2 - the Wald statistic obtained as Value divided by Std.Error2
p - the two-sided P-value based on normality of the statistic Z
p2 - the two-sided P-value based on normality of the statistic Z2

Further, we print:

Lambda - the optimal value of the smoothing hyperparameter
divided by the sample size, i.e., \(\lambda/n\) in the notation
of Kom<U+00E1>rek, Lesaffre and Hilton (2005)
Log(Lambda) - logarithm of the above
df - effective degrees of freedom of the model, see Section 2.2.3
of Kom<U+00E1>rek, Lesaffre and Hilton (2005)
AIC - Akaike's information criterion of the model, see Section 2.2.3
of Kom<U+00E1>rek, Lesaffre and Hilton (2005)

With argument spline set to TRUE, analogous table like that for the regression coefficients is printed also for the weights of the penalized Gaussian mixture (G-spline).

Usage

# S3 method for smoothSurvReg
print(x, spline, digits = min(options()$digits, 4), …)
# S3 method for smoothSurvReg
summary(object, spline, digits = min(options()$digits, 4), …)

Arguments

x

Object of class smoothSurvReg.

object

Object of class smoothSurvReg.

spline

TRUE/FALSE. If TRUE an information on fitted G-spline is printed.

digits

Controls the number of digits to print when printing numeric values. It is a suggestion only. Valid values are 1...22.

Further arguments passed to or from other methods.

References

Kom<U+00E1>rek, A., Lesaffre, E., and Hilton, J. F. (2005). Accelerated failure time model for arbitrarily censored data with smoothed error distribution. Journal of Computational and Graphical Statistics, 14, 726--745.

Lesaffre, E., Kom<U+00E1>rek, A., and Declerck, D. (2005). An overview of methods for interval-censored data with an emphasis on applications in dentistry. Statistical Methods in Medical Research, 14, 539--552.

See Also

smoothSurvReg, print, summary