Computes confidence intervals for one or more regression related parameters (regression coefficients, scale parameter or regression coefficients in a model for scale) for a 'smoothSurvReg' model.
# S3 method for smoothSurvReg
confint(object, parm, level = 0.95,
method = c("pseudo-variance", "asymptotic"), …)Object of class smoothSurvReg.
A specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
The confidence level required.
Type of confidence intervals to b calculated. Option “pseudo-variance” provides confidence intervals derived from inverted minus second derivatives of the penalized log-likelihood (pseudo-variance matrix), option “asymptotic” provides confidence intervals derived from the asyptotic covariance matrix of the parameter estimates.
Argument included in the function parameters for the compatibility with the generic function.
A matrix (or vector) with columns giving lower and upper confidence limits for each parameter. These will be labelled as (1 - level)/2 and 1 - (1 - level)/2 in % (by default 2.5 % and 97.5 %).