parm
A specification of which parameters are to be given
confidence intervals, either a vector of numbers or a vector of
names. If missing, all parameters are considered.
method
Type of confidence intervals to b calculated. Option
pseudo-variance provides confidence intervals derived from
inverted minus second derivatives of the penalized log-likelihood
(pseudo-variance matrix), option asymptotic provides
confidence intervals derived from the asyptotic covariance matrix
of the parameter estimates.